@@ -1,7 +1,7 @@
 package Plack::Response;
 use strict;
 use warnings;
-our $VERSION = '1.0037';
+our $VERSION = '1.0038';
 
 use Plack::Util::Accessor qw(body status);
 use Carp ();
@@ -86,20 +86,12 @@ sub finalize {
     my $self = shift;
     Carp::croak "missing status" unless $self->status();
 
-    my $headers = $self->headers;
-    my @headers;
-    $headers->scan(sub{
-        my ($k,$v) = @_;
-        $v =~ s/\015\012[\040|\011]+/chr(32)/ge; # replace LWS with a single SP
-        $v =~ s/\015|\012//g; # remove CR and LF since the char is invalid here
-        push @headers, $k, $v;
-    });
-
-    $self->_finalize_cookies(\@headers);
+    my $headers = $self->headers->flatten;
+    $self->_finalize_cookies($headers);
 
     return [
         $self->status,
-        \@headers,
+        $headers,
         $self->_body,
     ];
 }
